@@ -15,7 +15,7 @@ class BulkWriteOperations(object):
 		"""Creates an instance of BulkWriteOperations"""
 		pass
 
-	def upload_file(self, request, header_instance):
+	def upload_file(self, request, header_instance=None):
 		"""
 		The method to upload file
 
@@ -44,13 +44,13 @@ class BulkWriteOperations(object):
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + 'https://content.zohoapis.com/crm/v2/upload'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'multipart/form-data'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
-		handler_instance.header = header_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('multipart/form-data')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_header(header_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.action_response import ActionResponse
 		except Exception:
@@ -82,12 +82,12 @@ class BulkWriteOperations(object):
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/bulk/v2/write'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.action_response import ActionResponse
 		except Exception:
@@ -115,9 +115,9 @@ class BulkWriteOperations(object):
 		api_path = ''
 		api_path = api_path + '/crm/bulk/v2/write/'
 		api_path = api_path + str(job_id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.response_wrapper import ResponseWrapper
 		except Exception:
@@ -145,9 +145,9 @@ class BulkWriteOperations(object):
 		api_path = ''
 		api_path = api_path + '/'
 		api_path = api_path + str(download_url)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.response_handler import ResponseHandler
 		except Exception:
