@@ -1,9 +1,10 @@
+from .private import Private
 from .related_details import RelatedDetails
 from .crypt import Crypt
 from .module import Module
 from .view_type import ViewType
 from .lookup_field import LookupField
-from .fields_operations import FieldsOperations, GetFieldsParam
+from .fields_operations import FieldsOperations, GetFieldsParam, GetFieldParam
 from .multi_select_lookup import MultiSelectLookup
 from .tool_tip import ToolTip
 from .api_exception import APIException
