@@ -1,6 +1,6 @@
 from .api_exception import APIException
 from .response_handler import ResponseHandler
-from .profiles_operations import ProfilesOperations
+from .profiles_operations import ProfilesOperations, GetProfilesHeader, GetProfileHeader
 from .profile import Profile
 from .response_wrapper import ResponseWrapper
 from .section import Section
