@@ -120,6 +120,13 @@ class APIHTTPConnector(object):
             else:
                 response = requests.post(self.url, data=data, params=self.parameters, headers=self.headers, allow_redirects=False, proxies=proxies)
 
+        elif self.request_method == Constants.REQUEST_METHOD_PATCH:
+            data = None
+            if self.request_body is not None:
+                data = converter_instance.append_to_request(self, self.request_body)
+
+            response = requests.patch(self.url, data=data, headers=self.headers, params=self.parameters, allow_redirects=False, proxies=proxies)
+
         elif self.request_method == Constants.REQUEST_METHOD_DELETE:
             response = requests.delete(self.url, headers=self.headers, params=self.parameters, allow_redirects=False, proxies=proxies)
 
