@@ -1,4 +1,3 @@
-
 try:
     import json
     import platform
@@ -34,7 +33,6 @@ except Exception:
 
 
 class CommonAPIHandler(object):
-
     """
     This class to process the API request and its response.
     Construct the objects that are to be sent as parameters or request body with the API.
@@ -45,62 +43,219 @@ class CommonAPIHandler(object):
 
     def __init__(self):
 
-        self.api_path = None
-        self.header = HeaderMap()
-        self.param = ParameterMap()
-        self.request = None
-        self.http_method = None
-        self.module_api_name = None
-        self.content_type = None
-        self.category_method = None
-        self.mandatory_checker = None
+        self.__api_path = None
+        self.__header = HeaderMap()
+        self.__param = ParameterMap()
+        self.__request = None
+        self.__http_method = None
+        self.__module_api_name = None
+        self.__content_type = None
+        self.__category_method = None
+        self.__mandatory_checker = None
 
-    def add_param(self, param_name, param_value):
+    def set_api_path(self, api_path):
+        """
+        The method to set the API Path
+
+        Parameters:
+            api_path(str) : A string containing the API Path
+        """
+
+        self.__api_path = api_path
+
+    def get_api_path(self):
+        """
+        The method to get the API Path
+
+        Returns:
+            string: A string representing the API Path
+        """
+        return self.__api_path
+
+    def set_header(self, header):
+        """
+        The method to set the API request header map.
+
+        Parameters:
+            header(HeaderMap): A HeaderMap class instance containing the API request headers
+        """
+
+        if header is None:
+            return
+
+        if self.__header.request_headers is not None and self.__header.request_headers:
+            self.__header.request_headers.update(header.request_headers)
+        else:
+            self.__header = header
+
+    def set_param(self, param):
+        """
+        The method to set the API request parameter map.
+
+        Parameters:
+            param(ParameterMap) : A ParameterMap class instance containing the API request parameters
+        """
+
+        if param is None:
+            return
+
+        if self.__param.request_parameters is not None and self.__param.request_parameters:
+            self.__param.request_parameters.update(param.request_parameters)
+        else:
+            self.__param = param
+
+    def set_request(self, request):
+        self.__request = request
+
+    def set_http_method(self, http_method):
+        """
+        The method to set the HTTP Method
+
+        Parameters:
+            http_method(str):  A string containing the HTTP method.
+        """
+
+        self.__http_method = http_method
+
+    def get_http_method(self):
+        """
+        The method to get the HTTP Method
+
+        Returns:
+            string: A string representing the HTTP Method
+        """
+
+        return self.__http_method
+
+    def set_module_api_name(self, module_api_name):
+        """
+        The method to set the Module API Name
+
+        Parameters:
+            module_api_name(str):  A string containing the Module API Name
+        """
+
+        self.__module_api_name = module_api_name
+
+    def get_module_api_name(self):
+        """
+        The method to get the Module API Name
+
+        Returns:
+            string: A string representing the Module API Name
+        """
+
+        return self.__module_api_name
+
+    def set_content_type(self, content_type):
+        """
+        The method to set the Content Type
+
+        Parameters:
+            content_type(str):  A string containing the Content Type
+        """
+
+        self.__content_type = content_type
+
+    def set_category_method(self, category_method):
+        """
+        The method to set the Category Method
+
+        Parameters:
+            category_method(str):  A string containing the Category method.
+        """
+
+        self.__category_method = category_method
+
+    def get_category_method(self):
+        """
+        The method to get the Category Method
+
+        Returns:
+            string: A string representing the Category method.
+        """
+
+        return self.__category_method
+
+    def set_mandatory_checker(self, mandatory_checker):
+        """
+        The method to set the Mandatory Checker
+
+        Parameters:
+            mandatory_checker(bool): A boolean containing the Mandatory Checker.
+        """
+
+        self.__mandatory_checker = mandatory_checker
+
+    def get_mandatory_checker(self):
+        """
+        The method to get the Mandatory Checker
+
+        Returns:
+            bool: A boolean representing the Mandatory Checker.
+        """
+        return self.__mandatory_checker
+
+    def add_param(self, param_instance, param_value):
 
         """
         The method to add an API request parameter.
 
         Parameters:
-            param_name (str) : A string containing the API request parameter name.
+            param_instance (Param) : A Param instance containing the API request parameter.
             param_value (object) : An object containing the API request parameter value.
         """
 
-        if self.param is None:
-            self.param = ParameterMap()
+        if param_value is None:
+            return
 
-        self.param.add(Param(param_name), param_value)
+        if self.__param is None:
+            self.__param = ParameterMap()
 
-    def add_header(self, header_name, header_value):
+        self.__param.add(param_instance, param_value)
+
+    def add_header(self, header_instance, header_value):
 
         """
         The method to add an API request header.
 
         Parameters:
-            header_name (str) : A string containing the API request header name.
+            header_instance (Header) : A Header instance containing the API request header.
             header_value (object) : An object containing the API request header value.
         """
 
-        if self.header is None:
-            self.header = HeaderMap()
+        if header_value is None:
+            return
 
-        self.header.add(Header(header_name), header_value)
+        if self.__header is None:
+            self.__header = HeaderMap()
+
+        self.__header.add(header_instance, header_value)
 
     def api_call(self, class_name, encode_type):
 
         """
-        This method of constructing API request and response details. To make the Zoho CRM API calls.
-        :param class_name: A str containing the method return type.
-        :param encode_type: A str containing the expected API response content type.
-        :return:  A APIResponse representing the Zoho CRM API response instance or None.
-        :raise: SDKException
+        The method to construct API request and response details. To make the Zoho CRM API calls.
+
+        Parameters:
+            class_name(str): A str containing the method return type.
+            encode_type(str): A str containing the expected API response content type.
+
+        Returns:
+            APIResponse: An instance of APIResponse representing the Zoho CRM API response instance
+
+        Raises:
+            SDKException
         """
+
         try:
             from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
         except Exception:
             from ..initializer import Initializer
 
         if Initializer.get_initializer() is None:
-            raise SDKException(code=Constants.SDK_UNINITIALIZATION_ERROR, message=Constants.SDK_UNINITIALIZATION_MESSAGE)
+            raise SDKException(code=Constants.SDK_UNINITIALIZATION_ERROR,
+                               message=Constants.SDK_UNINITIALIZATION_MESSAGE)
 
         connector = APIHTTPConnector()
         try:
@@ -113,14 +268,14 @@ class CommonAPIHandler(object):
             CommonAPIHandler.logger.error(Constants.SET_API_URL_EXCEPTION + sdk_exception.__str__())
             raise sdk_exception
 
-        connector.request_method = self.http_method
-        connector.content_type = self.content_type
+        connector.request_method = self.__http_method
+        connector.content_type = self.__content_type
 
-        if self.header is not None and len(self.header.header_map) > 0:
-            connector.headers = self.header.header_map
+        if self.__header is not None and len(self.__header.request_headers) > 0:
+            connector.headers = self.__header.request_headers
 
-        if self.param is not None and len(self.param.parameter_map) > 0:
-            connector.parameters = self.param.parameter_map
+        if self.__param is not None and len(self.__param.request_parameters) > 0:
+            connector.parameters = self.__param.request_parameters
 
         try:
             Initializer.get_initializer().token.authenticate(connector)
@@ -134,10 +289,11 @@ class CommonAPIHandler(object):
 
         convert_instance = None
 
-        if self.content_type is not None and (self.http_method == Constants.REQUEST_METHOD_POST or self.http_method == Constants.REQUEST_METHOD_PUT or self.http_method == Constants.REQUEST_METHOD_PATCH):
+        if self.__content_type is not None and (
+                self.__http_method == Constants.REQUEST_METHOD_POST or self.__http_method == Constants.REQUEST_METHOD_PUT or self.__http_method == Constants.REQUEST_METHOD_PATCH):
             try:
-                convert_instance = self.get_converter_class_instance(self.content_type.lower())
-                request = convert_instance.form_request(self.request, self.request.__class__.__module__, 0, None)
+                convert_instance = self.get_converter_class_instance(self.__content_type.lower())
+                request = convert_instance.form_request(self.__request, self.__request.__class__.__module__, None, None)
             except SDKException as e:
                 CommonAPIHandler.logger.info(Constants.FORM_REQUEST_EXCEPTION + e.__str__())
                 raise e
@@ -149,7 +305,8 @@ class CommonAPIHandler(object):
             connector.request_body = request
 
         try:
-            connector.headers[Constants.ZOHO_SDK] = platform.system() + "/" + platform.release() + " python/" + platform.python_version() + ":" + Constants.SDK_VERSION
+            connector.headers[
+                Constants.ZOHO_SDK] = platform.system() + "/" + platform.release() + " python/" + platform.python_version() + ":" + Constants.SDK_VERSION
             response = connector.fire_request(convert_instance)
             return_object = None
 
@@ -222,24 +379,24 @@ class CommonAPIHandler(object):
 
         api_path = ''
 
-        if Constants.HTTP in self.api_path:
-            if Constants.CONTENT_API_URL in self.api_path:
+        if Constants.HTTP in self.__api_path:
+            if Constants.CONTENT_API_URL in self.__api_path:
                 api_path = Initializer.get_initializer().environment.file_upload_url
 
                 try:
-                    url_parse = urllib3.util.parse_url(self.api_path)
+                    url_parse = urllib3.util.parse_url(self.__api_path)
                     path = url_parse.path
                 except Exception as ex:
                     raise SDKException(code=Constants.INVALID_URL_ERROR, cause=ex)
 
                 api_path = api_path + path
             else:
-                if str(self.api_path)[:1].__eq__('/'):
-                    self.api_path = self.api_path[1:]
+                if str(self.__api_path)[:1].__eq__('/'):
+                    self.__api_path = self.__api_path[1:]
 
-                api_path = api_path + self.api_path
+                api_path = api_path + self.__api_path
         else:
             api_path = Initializer.get_initializer().environment.url
-            api_path = api_path + self.api_path
+            api_path = api_path + self.__api_path
 
         connector.url = api_path
