@@ -449,13 +449,13 @@ class Constants(object):
 
     REFRESH_ALL_MODULE_FIELDS_ERROR = "Exception in refreshing fields of all modules : "
 
-    GET_TOKENS_DB_ERROR = "Exception in getTokens - DBStore"
+    GET_TOKENS_DB_ERROR = "Exception in get_tokens - DBStore"
 
-    DELETE_TOKENS_DB_ERROR = "Exception in deleteTokens - DBStore"
+    DELETE_TOKENS_DB_ERROR = "Exception in delete_tokens - DBStore"
 
-    GET_TOKENS_FILE_ERROR = "Exception in getTokens - FileStore"
+    GET_TOKENS_FILE_ERROR = "Exception in get_tokens - FileStore"
 
-    DELETE_TOKENS_FILE_ERROR = "Exception in deleteTokens - FileStore"
+    DELETE_TOKENS_FILE_ERROR = "Exception in delete_tokens - FileStore"
 
     SDK_UNINITIALIZATION_ERROR = "SDK UNINITIALIZED ERROR"
 
@@ -514,3 +514,9 @@ class Constants(object):
     PROXY_USER = "User: "
 
     JSON_FILE_EXTENSION = ".json"
+
+    FILE_ERROR = "file_error"
+
+    FILE_DOES_NOT_EXISTS = "file does not exists"
+
+    CONSENT_LOOKUP = "consent_lookup"
