@@ -3,7 +3,7 @@ try:
     import re
     import json
     from zcrmsdk.src.com.zoho.crm.api.util.datatype_converter import DataTypeConverter
-    from zcrmsdk.src.com.zoho.api.exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
 
 except Exception:
@@ -11,12 +11,16 @@ except Exception:
     import re
     import json
     from .datatype_converter import DataTypeConverter
-    from zcrmsdk.src.com.zoho.api.exception import SDKException
+    from ..exception import SDKException
     from .constants import Constants
 
 
 class HeaderParamValidator(object):
 
+    """
+    This class validates the Header and Parameter values with the type accepted by the CRM APIs.
+    """
+
     def validate(self, header_param, value):
         name = header_param.name
         class_name = header_param.class_name
@@ -35,7 +39,7 @@ class HeaderParamValidator(object):
                     Constants.CLASS: json_class_name,
                     Constants.ACCEPTED_TYPE: type_detail[Constants.TYPE]
                 }
-                raise SDKException(Constants.TYPE_ERROR, None, error_details)
+                raise SDKException(code=Constants.TYPE_ERROR, details=error_details)
             else:
                 value = DataTypeConverter.post_convert(value, type_detail[Constants.TYPE])
 
