@@ -3,12 +3,10 @@ try:
     import importlib
     import logging
     import re
-    import traceback
     import json
 
 except Exception:
     import importlib
-    import traceback
     from .converter import Converter
     import logging
     import re
@@ -33,7 +31,7 @@ class XMLConverter(Converter):
 
         self.common_api_handler = common_api_handler
 
-    def form_request(self, request_object, pack, instance_number, lookup, skip_mandatory):
+    def form_request(self, request_object, pack, instance_number, class_member_detail):
 
         return None
 
